==> cmark-gfm-0.28.3.gfm.20-1-aarch64.pkg.tar.xz: usr/lib/cmake-gfm-extensions/cmark-gfm-extensions-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "libcmark-gfm-extensions" for configuration "Release"
set_property(TARGET libcmark-gfm-extensions APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(libcmark-gfm-extensions PROPERTIES
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "libcmark-gfm"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libcmark-gfm-extensions.so.0.28.3.gfm.20"
  IMPORTED_SONAME_RELEASE "libcmark-gfm-extensions.so.0.28.3.gfm.20"
  )

list(APPEND _IMPORT_CHECK_TARGETS libcmark-gfm-extensions )
list(APPEND _IMPORT_CHECK_FILES_FOR_libcmark-gfm-extensions "${_IMPORT_PREFIX}/lib/libcmark-gfm-extensions.so.0.28.3.gfm.20" )

# Import target "libcmark-gfm-extensions_static" for configuration "Release"
set_property(TARGET libcmark-gfm-extensions_static APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(libcmark-gfm-extensions_static PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "C"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libcmark-gfm-extensions.a"
  )

list(APPEND _IMPORT_CHECK_TARGETS libcmark-gfm-extensions_static )
list(APPEND _IMPORT_CHECK_FILES_FOR_libcmark-gfm-extensions_static "${_IMPORT_PREFIX}/lib/libcmark-gfm-extensions.a" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> cmark-gfm-0.29.0.gfm.13-1-aarch64.pkg.tar.xz: usr/lib/cmake-gfm-extensions/cmark-gfm-extensions-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "libcmark-gfm-extensions" for configuration "Release"
set_property(TARGET libcmark-gfm-extensions APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(libcmark-gfm-extensions PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libcmark-gfm-extensions.so.0.29.0.gfm.13"
  IMPORTED_SONAME_RELEASE "libcmark-gfm-extensions.so.0.29.0.gfm.13"
  )

list(APPEND _cmake_import_check_targets libcmark-gfm-extensions )
list(APPEND _cmake_import_check_files_for_libcmark-gfm-extensions "${_IMPORT_PREFIX}/lib/libcmark-gfm-extensions.so.0.29.0.gfm.13" )

# Import target "libcmark-gfm-extensions_static" for configuration "Release"
set_property(TARGET libcmark-gfm-extensions_static APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(libcmark-gfm-extensions_static PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "C"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libcmark-gfm-extensions.a"
  )

list(APPEND _cmake_import_check_targets libcmark-gfm-extensions_static )
list(APPEND _cmake_import_check_files_for_libcmark-gfm-extensions_static "${_IMPORT_PREFIX}/lib/libcmark-gfm-extensions.a" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
